==> google-displayvideo-clj-0.12.5.jar: com/adgoji/displayvideo_api/advertisers/channels.clj <==
(ns com.adgoji.displayvideo-api.advertisers.channels
  (:require
   [clojure.spec.alpha :as s]
   [com.adgoji.displayvideo-spec.interface :as displayvideo-spec]
   [com.adgoji.advertisers-channels.interface :as channels]))

(defn create
  "Create a new channel"
  [client advertiser-id channel]
  (channels/create client advertiser-id channel))

(s/fdef create
  :args (s/cat :client ::displayvideo-spec/displayvideo-client
               :advertiser-id ::displayvideo-spec/advertiser-id
               :channel ::displayvideo-spec/channel)
  :ret ::displayvideo-spec/channel)

(defn update-by-id
  "Update an existing channel by `advertiser-id` and `channel-id`.

  Request body is the same as for [[create]] function. Additionally
  `update-mask` is a mandatory parameter, it should be a sequence of
  fully qualified names of fields (as keywords)."
  [client advertiser-id channel-id channel update-mask]
  (channels/update-by-id client
                         advertiser-id
                         channel-id
                         channel
                         update-mask))

(s/fdef update-by-id
  :args (s/cat :client ::displayvideo-spec/displayvideo-client
               :advertiser-id ::displayvideo-spec/advertiser-id
               :channel-id ::displayvideo-spec/channel-id
               :channel ::displayvideo-spec/channel
               :update-mask ::displayvideo-spec/update-mask)
  :ret ::displayvideo-spec/channel)

(defn get-list
  "Returns a list of all advertiser's channels."
  [client advertiser-id opts]
  (channels/get-list client advertiser-id opts))

(s/fdef get-list
  :args (s/cat :client ::displayvideo-spec/displayvideo-client
               :advertiser-id ::displayvideo-spec/advertiser-id
               :opts (s/keys :opt-un [::displayvideo-spec/order-by
                                      ::displayvideo-spec/filter-expr
                                      ::displayvideo-spec/limit]))
  :ret ::displayvideo-spec/channels)

(defn get-by-id
  "Get a single channel by `advertiser-id` and `channel-id`."
  [client advertiser-id channel-id]
  (channels/get-by-id client advertiser-id channel-id))

(s/fdef get-by-id
  :args (s/cat :client ::displayvideo-spec/displayvideo-client
               :advertiser-id ::displayvideo-spec/advertiser-id
               :channel-id ::displayvideo-spec/channel-id)
  :ret ::displayvideo-spec/channel)

==> google-displayvideo-clj-2.1.0.jar: com/adgoji/displayvideo_api/advertisers/channels.clj <==
(ns com.adgoji.displayvideo-api.advertisers.channels
  (:require
   [clojure.spec.alpha :as s]
   [com.adgoji.displayvideo-spec.interface :as displayvideo-spec]
   [com.adgoji.advertisers-channels.interface :as channels]))

(defn create
  "Create a new channel"
  [client advertiser-id channel]
  (channels/create client advertiser-id channel))

(s/fdef create
  :args (s/cat :client ::displayvideo-spec/displayvideo-client
               :advertiser-id ::displayvideo-spec/advertiser-id
               :channel ::displayvideo-spec/channel)
  :ret ::displayvideo-spec/channel)

(defn update-by-id
  "Update an existing channel by `advertiser-id` and `channel-id`.

  Request body is the same as for [[create]] function. Additionally
  `update-mask` is a mandatory parameter, it should be a sequence of
  fully qualified names of fields (as keywords)."
  [client advertiser-id channel-id channel update-mask]
  (channels/update-by-id client
                         advertiser-id
                         channel-id
                         channel
                         update-mask))

(s/fdef update-by-id
  :args (s/cat :client ::displayvideo-spec/displayvideo-client
               :advertiser-id ::displayvideo-spec/advertiser-id
               :channel-id ::displayvideo-spec/channel-id
               :channel ::displayvideo-spec/channel-update
               :update-mask ::displayvideo-spec/update-mask)
  :ret ::displayvideo-spec/channel)

(defn get-list
  "Returns a list of all advertiser's channels."
  [client advertiser-id opts]
  (channels/get-list client advertiser-id opts))

(s/fdef get-list
  :args (s/cat :client ::displayvideo-spec/displayvideo-client
               :advertiser-id ::displayvideo-spec/advertiser-id
               :opts (s/keys :opt-un [::displayvideo-spec/order-by
                                      ::displayvideo-spec/filter-expr
                                      ::displayvideo-spec/limit]))
  :ret ::displayvideo-spec/channels)

(defn get-by-id
  "Get a single channel by `advertiser-id` and `channel-id`."
  [client advertiser-id channel-id]
  (channels/get-by-id client advertiser-id channel-id))

(s/fdef get-by-id
  :args (s/cat :client ::displayvideo-spec/displayvideo-client
               :advertiser-id ::displayvideo-spec/advertiser-id
               :channel-id ::displayvideo-spec/channel-id)
  :ret ::displayvideo-spec/channel)
